@@ -13,18 +13,21 @@ def uploaded_filepath(instance, filename):
 
 SETTINGS_USER = getattr(settings, 'SUMMERNOTE_CONFIG', {})
 SETTINGS_DEFAULT = {
+    'iframe': True,
     'width': 720,
     'height': 480,
     'toolbar': [
         ['style', ['style']],
         ['font', ['bold', 'italic', 'underline', 'clear']],
+        ['fontname', ['fontname']],
         ['fontsize', ['fontsize']],
         ['color', ['color']],
         ['para', ['ul', 'ol', 'paragraph']],
         ['height', ['height']],
         ['table', ['table']],
-        ['insert', ['link', 'picture']],
-        ['misc', ['codeview', 'help']]
+        ['insert', ['link', 'picture', 'video']],
+        ['view', ['fullscreen', 'codeview']],
+        ['help', ['help']],
     ],
     'lang': 'en-US',
 
